<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
    <xsl:output encoding="UTF-8" method="html" indent="yes" doctype-system="about:legacy-compat"/>

    <!-- stylesheet-links -->
    <xsl:variable name="jQuerySrc">js/jquery.js</xsl:variable>
    <xsl:variable name="saltinfojs">js/saltinfo.js</xsl:variable>
    <xsl:variable name="saltinfocss">css/saltinfo.css</xsl:variable>
    <xsl:variable name="indexcss">css/index.css</xsl:variable>

    <!-- logo and alternative logo for internet-explorer -->
    <xsl:variable name="logoSrc">https://korpling.german.hu-berlin.de/saltnpepper/salt/info/info-10/img/SaltNPepper_logo2010.svg</xsl:variable>
    <xsl:variable name="logoAlternative">https://korpling.german.hu-berlin.de/saltnpepper/salt/info/info-10/img/SaltNPepper_logo2010_large.png</xsl:variable>

    <xsl:template match="/">
        <html>
            <head>
                
                <title><xsl:value-of select="node()/@sName"/>-Overview</title>
                <xsl:call-template name="MetaInfo"/>
                <!--<xsl:call-template name="JavaScriptElem"/>-->
            </head>
            <body>
                <xsl:call-template name="HeadOfHtml"/>
                <div id="container">
                   
                    <div id="navigation">
                        <xsl:apply-templates mode="navi"/>
                    </div>
                    
    
                  <!--  <xsl:call-template name="navigation"/>-->
                    <xsl:call-template name="content"/>
                   
                </div>
                <xsl:call-template name="Footer"/>
                <xsl:call-template name="html-tooltips"></xsl:call-template>
            </body>
        </html>


    </xsl:template>
    
    <xsl:template mode="navi" match="text()|@*"></xsl:template>

    <xsl:template mode="navi" match="sCorpusInfo[@rel-location]|saltProjectInfo[@rel-location]">
        <li class="scorpus-item">
            <xsl:call-template name="scorpus-link"/>
            <ul>
                <xsl:apply-templates mode="navi" select="sDocumentInfo|sCorpusInfo|saltProjectInfo">
                    <xsl:sort select="current()/@sName"/>
                </xsl:apply-templates>
            </ul>
        </li>
       
    </xsl:template>
    
    <xsl:template mode="navi" match="sDocumentInfo[@rel-location]">
        <li>
            <xsl:call-template name="scorpus-link"/>
        </li>
    </xsl:template>
    
    <!-- Creates the link + fake id data attribute to generate the browser history    -->
    <xsl:template name="scorpus-link">
        <a>
            <xsl:attribute name="class">nav-link</xsl:attribute>
            <xsl:attribute name="href" ><xsl:value-of select="substring-before(@rel-location,'.xml')"/>.html</xsl:attribute>
            <xsl:attribute name="data-id"><xsl:value-of select="@rel-location"/></xsl:attribute>
            <xsl:attribute name="target">content</xsl:attribute>
            <xsl:value-of select="@sName"/>
        </a>
    </xsl:template>

    <!-- get html-stylesheet -->
    <xsl:template name="MetaInfo">
        <!-- <link href="{$treecss}" rel="StyleSheet" type="text/css"/> -->
        <link href="{$saltinfocss}" rel="StyleSheet" type="text/css"/>
        <link href="{$indexcss}" rel="StyleSheet" type="text/css"/>
        <script src="{$jQuerySrc}" type="text/javascript"/>
        <script src="{$saltinfojs}" type="text/javascript"/>
    </xsl:template>


    <!-- create the header of the html -->
    <xsl:template name="HeadOfHtml">
        <div id="header">
            <img alt="{$logoAlternative}" href="http://korpling.german.hu-berlin.de/saltnpepper" src="{$logoSrc}"/>
            <h1>
                <xsl:value-of select="node()/@sName"/>
                <xsl:text>- Overview</xsl:text>
            </h1>
        </div>
    </xsl:template>

    <!-- create the clickable tree-table -->
    <xsl:template name="content">
        <div id="content">
           <!-- <iframe>
                <xsl:attribute name="src">

                </xsl:attribute>
                <xsl:attribute name="name">content</xsl:attribute>
            </iframe>-->
        </div>
    </xsl:template>

    <!-- create html-footer -->
    <xsl:template name="Footer">
        <div id="footer">
            <xsl:text>this site was generated by </xsl:text> 
            <a href="https://github.com/korpling/pepperModules-SaltInfoModules">SaltInfoModules</a>
            <xsl:text> a plugin for </xsl:text>
            <a href="https://github.com/korpling/pepper">Pepper</a> 
            <xsl:text> and was generated on </xsl:text>
            <xsl:value-of select="/saltProjectInfo/@generatedOn"/>
            <div class="impressum">
                <a href="http://korpling.german.hu-berlin.de/saltnpepper/salt/info/info-10/impressum.html">
                    <xsl:text>Impressum</xsl:text></a>
            </div>
        </div>
    </xsl:template>
    
    <xsl:template name="html-tooltips">
        <div class="data-tooltips">
             
            <p style="display:none" id="Default" class="tooltip-text">No description available.</p>
            
        </div>
    </xsl:template>
</xsl:stylesheet>
